/*
*  program name: Rubrica -- http://digilander.iol.it/nfragale/download.html
*  file: prefer_int.c
*  
*  build the graphic interface for preferences dialog
*
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <gconf/gconf-client.h>
#include <gconf/gconf-value.h>
#include <gconf/gconf-schema.h>
#include <gnome.h>

#include "prefer_cb.h"
#include "prefer_int.h"
#include "prefer.h"
#include "support.h"
#include "error.h"




GtkWidget *preferences_dialog;
GtkWidget *notebook;
GtkTooltips *tooltips;


GtkWidget* rubrica_preferences_get_preferencesbox(void)
{
  return (GtkWidget*) preferences_dialog;
}


GtkWidget*
create_preferences_dialog (GConfClient *client)
{
  GConfChangeSet *cs;

  GtkWidget *dialog_vbox;
  GtkWidget *dialog_action_area2;

  GtkWidget *ok;
  GtkWidget *apply;
  GtkWidget *revert;
  GtkWidget *close;

  GtkWidget *frame;
  GtkWidget *tab;

  preferences_dialog = gnome_dialog_new (_("Rubrica Preferences"), NULL);
  notebook           = gtk_notebook_new ();
  tooltips           = gtk_tooltips_new ();
  cs                 = gconf_change_set_new();

  rubrica_preferences_reset_errors();

  gtk_widget_set_name (preferences_dialog, "preferences_dialog");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "preferences_dialog", 
		       preferences_dialog);
  GTK_WINDOW (preferences_dialog)->type = GTK_WINDOW_DIALOG;
  gtk_window_set_position (GTK_WINDOW (preferences_dialog), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (preferences_dialog), TRUE);
  gtk_window_set_policy (GTK_WINDOW (preferences_dialog), FALSE, FALSE, FALSE);

  dialog_vbox = GNOME_DIALOG (preferences_dialog)->vbox;
  gtk_container_set_border_width (GTK_CONTAINER (dialog_vbox), 2);
  gtk_widget_show (dialog_vbox);

  gtk_box_pack_start (GTK_BOX (dialog_vbox), notebook, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (notebook), 2);

  /*      Configuration pages of notebook 
	  Add here new pages
  */
  frame = rubrica_preferences_add_files_page(client);
  tab = gtk_label_new (_("File"));
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, tab);

  frame = rubrica_preferences_add_general_page(client);
  tab = gtk_label_new (_("General"));
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, tab);

  frame = rubrica_preferences_add_translation_page(client);
  tab = gtk_label_new (_("Translation"));
  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, tab);
  /*      --------------------- 
  */
  gtk_widget_show (notebook);
  
  if (rubrica_preferences_there_are_errors())
    {
      gtk_window_set_modal (GTK_WINDOW (preferences_dialog), FALSE);
      error_preferences_key_load(rubrica_preferences_get_buffer_error());      
      gtk_window_set_modal (GTK_WINDOW (preferences_dialog), TRUE);      
    }

  dialog_action_area2 = GNOME_DIALOG (preferences_dialog)->action_area;
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area2), GTK_BUTTONBOX_END);
  gtk_button_box_set_spacing (GTK_BUTTON_BOX (dialog_action_area2), 5);
  gtk_button_box_set_child_size (GTK_BUTTON_BOX (dialog_action_area2), 80, 27);
  gtk_button_box_set_child_ipadding (GTK_BUTTON_BOX (dialog_action_area2), 5, 0);
  gtk_widget_show (dialog_action_area2);

  gnome_dialog_append_button (GNOME_DIALOG (preferences_dialog), 
			      GNOME_STOCK_BUTTON_OK);
  ok = GTK_WIDGET (g_list_last (GNOME_DIALOG (preferences_dialog)->buttons)->data);
  GTK_WIDGET_SET_FLAGS (ok, GTK_CAN_DEFAULT);
  gtk_widget_set_name (ok, "ok");
  gtk_widget_show (ok);

  gnome_dialog_append_button (GNOME_DIALOG (preferences_dialog), 
			      GNOME_STOCK_BUTTON_APPLY);
  apply = GTK_WIDGET (g_list_last (GNOME_DIALOG (preferences_dialog)->buttons)->data);
  GTK_WIDGET_SET_FLAGS (apply, GTK_CAN_DEFAULT);
  gtk_widget_show (apply);

  gnome_dialog_append_button_with_pixmap (GNOME_DIALOG (preferences_dialog),
                                          _("Revert"), GNOME_STOCK_PIXMAP_REVERT);
  revert = GTK_WIDGET (g_list_last (GNOME_DIALOG (preferences_dialog)->buttons)->data);
  GTK_WIDGET_SET_FLAGS (revert, GTK_CAN_DEFAULT);
  gtk_widget_show (revert);

  gnome_dialog_append_button (GNOME_DIALOG (preferences_dialog), 
			      GNOME_STOCK_BUTTON_CLOSE);
  close = GTK_WIDGET (g_list_last (GNOME_DIALOG (preferences_dialog)->buttons)->data);
  GTK_WIDGET_SET_FLAGS (close, GTK_CAN_DEFAULT);
  gtk_widget_show (close);

  gtk_widget_set_sensitive(ok, FALSE);
  gtk_widget_set_sensitive(apply, FALSE);
  gtk_widget_set_sensitive(revert, FALSE);

  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "ok", ok);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "apply", apply);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "revert", revert);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "close", close);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "client", client);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "tooltips", tooltips);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "changeset", cs);
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "notebook", notebook);

  gtk_signal_connect (GTK_OBJECT (ok), "clicked",
                      GTK_SIGNAL_FUNC (rubrica_preferences_ok_clicked),
                      preferences_dialog);

  gtk_signal_connect (GTK_OBJECT (apply), "clicked",
                      GTK_SIGNAL_FUNC (rubrica_preferences_apply_clicked),
                      preferences_dialog);

  gtk_signal_connect (GTK_OBJECT (revert), "clicked",
                      GTK_SIGNAL_FUNC (rubrica_preferences_revert_clicked),
                      preferences_dialog);

  gtk_signal_connect (GTK_OBJECT (close), "clicked",
                      GTK_SIGNAL_FUNC (rubrica_preferences_close_dialog), 
                      preferences_dialog); 

  return preferences_dialog;
}


GtkWidget *rubrica_preferences_add_files_page(GConfClient *client)
{
  GtkWidget *file_frame;

  GtkWidget *box_file;
  GtkWidget *table_show;
  GtkWidget *box_addbook;
  GtkWidget *box_folder;
  GtkWidget *box_backup;
  GtkWidget *box_main_compress;
  GtkWidget *box_compression;
  GtkWidget *box_compression_rate;

  GtkWidget *show_frame;
  GtkWidget *addbook_frame;
  GtkWidget *folder_frame;
  GtkWidget *backup_frame;
  GtkWidget *compress_frame;

  GtkWidget *check_path;
  GtkWidget *check_addbook;
  GtkWidget *check_folder;
  GtkWidget *check_backup;
  GtkWidget *check_compress;

  GtkWidget *fileentry_addbook;
  GtkWidget *fileentry_folder;
  GtkWidget *entry_addbook;
  GtkWidget *entry_folder;

  GtkWidget *label_compress_rate;
  GtkObject *spin_rate_adj;
  GtkWidget *spin_rate;


  file_frame = gtk_frame_new (_(" Files settings "));
  gtk_container_set_border_width (GTK_CONTAINER (file_frame), 2);
  gtk_widget_show (file_frame);

  box_file = gtk_vbox_new (FALSE, 2);
  gtk_widget_show (box_file);
  gtk_container_add (GTK_CONTAINER (file_frame), box_file);

  show_frame = gtk_frame_new (_(" Show "));
  gtk_widget_show (show_frame);
  gtk_box_pack_start (GTK_BOX (box_file), show_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (show_frame), 2);

  table_show = gtk_table_new (1, 1, TRUE);
  gtk_widget_show (table_show);
  gtk_container_add (GTK_CONTAINER (show_frame), table_show);
  gtk_container_set_border_width (GTK_CONTAINER (table_show), 2);

  /*    Show:
	- by default, only file name is show
	- check to show path too

	CHECK BUTTON:
	SHOW FILE
  */
  check_path = gtk_check_button_new_with_label (_("Show addressbook's path"));
  gtk_widget_set_name (check_path, "check_path");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_SHOW, check_path);
  gtk_widget_show (check_path);

  gtk_table_attach (GTK_TABLE (table_show), check_path, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_path), 2);
  gtk_tooltips_set_tip (tooltips, check_path, 
			_("Show the path of current addressbook "), NULL);

  /* ---------------------------------------------------------------------
     GConf settings 
     ---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(check_path, client, RUBRICA_KEY_SHOW);

  /* ---------------------------------------------------------------------  */
  
  /*    -----------------------------------------------------------------------
	load Address book at rubrica start
	use a default folder to save addressbooks

	- check_addbook   
	    - true:  load addressbook at start
	    - false: start with void addressbook

	    - entry: addressbook file name
	
	- check_folder
	    - true:  use the setted directory as default folder
	    - false  save addressbook in current directory

	    - entry: directory name
	-----------------------------------------------------------------------
  */
  addbook_frame = gtk_frame_new (_(" Default address book "));
  gtk_box_pack_start (GTK_BOX (box_file), addbook_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (addbook_frame), 2);
  gtk_widget_show (addbook_frame);

  box_addbook = gtk_vbox_new (FALSE, 0);
  gtk_container_add (GTK_CONTAINER (addbook_frame), box_addbook);
  gtk_widget_show (box_addbook);

  /*    CHECK BUTTON
	CHECK ADDRESS BOOK
   */
  check_addbook = gtk_check_button_new_with_label(_("Load this addressbook at start"));
  gtk_widget_set_name (check_addbook, "check_addbook");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_HAVE_BOOK,
		       check_addbook);
  gtk_box_pack_start (GTK_BOX (box_addbook), check_addbook, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_addbook), 2);
  gtk_widget_show (check_addbook);

  /*    GNOME FILE ENTRY
	ADDRESS BOOK
  */
  fileentry_addbook = gnome_file_entry_new ("histoty_start", NULL);
  gtk_widget_set_name (fileentry_addbook, "fileentry_addbook");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_BOOK, 
		       fileentry_addbook);
  gtk_box_pack_start (GTK_BOX (box_addbook), fileentry_addbook, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (fileentry_addbook), 2);
  gnome_file_entry_set_modal (GNOME_FILE_ENTRY (fileentry_addbook), TRUE);
  gtk_widget_show (fileentry_addbook);

  /*    FILE ENTRY
	ADDRESS BOOK
  */  
  entry_addbook = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (fileentry_addbook));
  gtk_widget_set_name (entry_addbook, "entry_addbook");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_addbook", 
		       entry_addbook);
  gtk_entry_set_text (GTK_ENTRY (entry_addbook), "~/.rubrica/rubrica.rub");
  gtk_widget_show (entry_addbook);

  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_checked_entry(check_addbook, fileentry_addbook,
					      entry_addbook, client,
					      RUBRICA_KEY_HAVE_BOOK, 
					      RUBRICA_KEY_BOOK);
  /*    ---------------------------------------------------------------------  */

  folder_frame = gtk_frame_new (_(" Default folder "));
  gtk_box_pack_start (GTK_BOX (box_file), folder_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (folder_frame), 2);
  gtk_widget_show (folder_frame);

  box_folder = gtk_vbox_new (FALSE, 0);
  gtk_container_add (GTK_CONTAINER (folder_frame), box_folder);
  gtk_widget_show (box_folder);

  /*    CHECK FOLDER
   */
  check_folder = gtk_check_button_new_with_label 
    (_("Save addressbooks in this folder by default"));
  gtk_widget_set_name (check_folder, "check_folder");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_HAVE_FOLDER, 
		       check_folder);
  gtk_box_pack_start (GTK_BOX (box_folder), check_folder, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_folder), 2);
  gtk_widget_show (check_folder);

  /*    GNOME FILE ENTRY
	FOLDER
  */
  fileentry_folder = gnome_file_entry_new ("history_folder", _("Choose a folder"));
  gtk_widget_set_name (fileentry_folder, "fileentry_folder");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_FOLDER, 
		       fileentry_folder);
  gtk_box_pack_start (GTK_BOX (box_folder), fileentry_folder, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (fileentry_folder), 2);
  gnome_file_entry_set_modal (GNOME_FILE_ENTRY (fileentry_folder), TRUE);
  gtk_widget_show (fileentry_folder);

  /*    FILE ENTRY
	FOLDER
  */ 
  entry_folder = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (fileentry_folder));
  gtk_widget_set_name (entry_folder, "entry_folder");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_folder", 
		       entry_folder);
  gtk_widget_show (entry_folder);
  gtk_entry_set_text (GTK_ENTRY (entry_folder), "~/.rubrica/");

  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_checked_entry(check_folder, fileentry_folder,
					      entry_folder, client, 
					      RUBRICA_KEY_HAVE_FOLDER,
					      RUBRICA_KEY_FOLDER);
  /*    ---------------------------------------------------------------------  */

  /*    Backup:
	- do backup before overwrite 

	default: don't do backup

	CHECK BUTTON
	BACKUP ALWAYS
  */ 
  backup_frame = gtk_frame_new (_(" Backup "));
  gtk_box_pack_start (GTK_BOX (box_file), backup_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (backup_frame), 2);
  gtk_widget_show (backup_frame);

  box_backup = gtk_hbox_new (TRUE, 0);
  gtk_container_add (GTK_CONTAINER (backup_frame), box_backup);
  gtk_container_set_border_width (GTK_CONTAINER (box_backup), 2);
  gtk_widget_show (box_backup);

  /*    CHECK BUTTON BACKUP 
  */
  check_backup = gtk_check_button_new_with_label 
    (_("Make backup of previous file before overwrite"));
  gtk_widget_set_name (check_backup, "check_backup");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_BACKUP, 
		       check_backup);
  gtk_box_pack_start (GTK_BOX (box_backup), check_backup, TRUE, TRUE, 0);
  gtk_widget_show (check_backup);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(check_backup, client, RUBRICA_KEY_BACKUP);
  /*    ---------------------------------------------------------------------  */

  /*    Compress addressbook:
	- compression check button        
	- compression rate spin button

	default: not zip, compression rate: 0

	CHECK BUTTON
	COMPRESS ADDRESSBOOK FILE
  */
  compress_frame = gtk_frame_new (_(" Compression "));
  gtk_box_pack_start (GTK_BOX (box_file), compress_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (compress_frame), 2);
  gtk_widget_show (compress_frame);

  box_main_compress = gtk_vbox_new (TRUE, 0);
  gtk_container_add (GTK_CONTAINER (compress_frame), box_main_compress);
  gtk_container_set_border_width (GTK_CONTAINER (box_main_compress), 2);
  gtk_widget_show (box_main_compress);

  box_compression = gtk_hbox_new (TRUE, 0);
  gtk_box_pack_start (GTK_BOX (box_main_compress), box_compression, FALSE, FALSE, 0);
  gtk_widget_show (box_compression);

  /*    CHECK BUTTON COMPRESS ADDRESSBOOK FILE
  */
  check_compress = gtk_check_button_new_with_label (_("Compress addressbook"));
  gtk_widget_set_name (check_compress, "check_compress");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_COMPRESS, 
		       check_compress);
  gtk_box_pack_start (GTK_BOX (box_compression), check_compress, TRUE, TRUE, 0);
  gtk_widget_show (check_compress);

  box_compression_rate = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (box_compression_rate, "box_compression_rate");
  gtk_box_pack_end(GTK_BOX(box_main_compress), box_compression_rate, FALSE, FALSE, 0);
  gtk_widget_show (box_compression_rate);

  label_compress_rate = gtk_label_new (_("Compression rate:"));
  gtk_widget_set_name (label_compress_rate, "label_compress_rate");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "label_compress_rate", 
		       label_compress_rate);
  gtk_box_pack_start(GTK_BOX(box_compression_rate),label_compress_rate,FALSE,TRUE, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label_compress_rate), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label_compress_rate), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_compress_rate), 3, 0);
  gtk_widget_show (label_compress_rate);

  /*    SPIN BUTTON
	COMPRESSION RATE
  */  
  spin_rate_adj = gtk_adjustment_new (0, 0, 9, 1, 1, 1);
  spin_rate = gtk_spin_button_new (GTK_ADJUSTMENT (spin_rate_adj), 1, 0);
  gtk_widget_set_name (spin_rate, "spin_rate");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_RATE, 
		       spin_rate);
  gtk_box_pack_start (GTK_BOX (box_compression_rate), spin_rate, FALSE, FALSE, 68);
  gtk_tooltips_set_tip (tooltips, spin_rate,
			_("0 not compressed, 9 max compression rate"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spin_rate), TRUE);
  gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (spin_rate), FALSE);
  gtk_widget_show (spin_rate);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_spin(check_compress, spin_rate, client, 
				     RUBRICA_KEY_COMPRESS,
				     RUBRICA_KEY_RATE);
  /*    ---------------------------------------------------------------------  */

  /*    SHOW PATH CALLBACK
  */
  gtk_signal_connect (GTK_OBJECT (check_path), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
                      RUBRICA_KEY_SHOW);

  /*    LOAD DEFAULT ADDRESS BOOK CALLBACK
  */
  gtk_signal_connect (GTK_OBJECT (check_addbook), "toggled",
                      GTK_SIGNAL_FUNC (on_check_files_toggled),
		      RUBRICA_KEY_HAVE_BOOK);
  gtk_signal_connect (GTK_OBJECT (entry_addbook), "changed",
		      GTK_SIGNAL_FUNC (on_entry_files_changed),
                      RUBRICA_KEY_BOOK);
  
  /*    USE DEFAULT FOLDER CALLBACK
  */
  gtk_signal_connect (GTK_OBJECT (check_folder), "toggled",
                      GTK_SIGNAL_FUNC (on_check_files_toggled),
		      RUBRICA_KEY_HAVE_FOLDER);
  gtk_signal_connect (GTK_OBJECT (entry_folder), "changed",
                      GTK_SIGNAL_FUNC (on_entry_files_changed),
                      RUBRICA_KEY_FOLDER);

  /*    BACKUP CALLBACK
  */
  gtk_signal_connect (GTK_OBJECT (check_backup), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
                      RUBRICA_KEY_BACKUP);

  /*    COMPRESS CALLBACK
  */
  gtk_signal_connect (GTK_OBJECT (check_compress), "toggled",
                      GTK_SIGNAL_FUNC (on_check_compress_toggled),
		      RUBRICA_KEY_COMPRESS);
  gtk_signal_connect (GTK_OBJECT (spin_rate), "activate",
                      GTK_SIGNAL_FUNC (on_spin_rate_activate),
                      RUBRICA_KEY_RATE);
  gtk_signal_connect (GTK_OBJECT (spin_rate), "changed",
                      GTK_SIGNAL_FUNC (on_spin_rate_activate),
                      RUBRICA_KEY_RATE);

  return (GtkWidget *) file_frame;
}



GtkWidget *rubrica_preferences_add_general_page(GConfClient *client)
{
  GtkWidget *general_frame;

  GtkWidget *box_general;
  GtkWidget *box_order;
  GtkWidget *box_search;
  GtkWidget *box_exit;
  GtkWidget *box_tips;

  GtkWidget *table1;
  GtkWidget *table2;

  GSList *opt_ordine_group = NULL;
  GSList *opt_string_search_group = NULL;

  GtkWidget *radio_complete;
  GtkWidget *radio_incomplete;

  GtkWidget *ordering_frame;
  GtkWidget *search_frame;
  GtkWidget *exit_frame;
  GtkWidget *tips_frame;

  GtkWidget *radio_alpha;
  GtkWidget *radio_date;

  GtkWidget *check_increase;
  GtkWidget *check_case_search;
  GtkWidget *check_exit;
  GtkWidget *check_tips;

  GtkWidget *label_show;
  GtkWidget *label_search;


  general_frame = gtk_frame_new (_(" General "));
  gtk_container_set_border_width (GTK_CONTAINER (general_frame), 2);
  gtk_widget_show (general_frame);

  box_general = gtk_vbox_new (FALSE, 0);
  gtk_container_add (GTK_CONTAINER (general_frame), box_general);
  gtk_container_set_border_width (GTK_CONTAINER (box_general), 2);
  gtk_widget_show (box_general);

  /*    Ordering:
	- increasing   (true)
	- decreasing   (false)

	default: increasing 
  */
  ordering_frame = gtk_frame_new (_(" Ordering "));
  gtk_box_pack_start (GTK_BOX (box_general), ordering_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (ordering_frame), 2);
  gtk_widget_show (ordering_frame);

  box_order = gtk_vbox_new (TRUE, 0);
  gtk_container_add (GTK_CONTAINER (ordering_frame), box_order);
  gtk_container_set_border_width (GTK_CONTAINER (box_order), 2);
  gtk_widget_show (box_order);

  table1 = gtk_table_new (2, 3, TRUE);
  gtk_widget_show (table1);

  gtk_box_pack_start (GTK_BOX (box_order), table1, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table1), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table1), 5);

  label_show = gtk_label_new (_("Show cards:  "));
  gtk_widget_show (label_show);

  gtk_table_attach (GTK_TABLE (table1), label_show, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_show), GTK_JUSTIFY_LEFT);
  gtk_label_set_line_wrap (GTK_LABEL (label_show), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label_show), 1.93715e-07, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_show), 5, 0);

  /* 
     CHECK BUTTON: INCREASE
  */
  check_increase = gtk_check_button_new_with_label (_("Ordering is increasing"));
  gtk_widget_set_name (check_increase, "check_increase");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_INCREASE, 
		       check_increase);
  gtk_table_attach (GTK_TABLE (table1), check_increase, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_increase), 2);
  gtk_tooltips_set_tip (tooltips, check_increase, 
			_("Uncheck for decreasing ordering"), NULL);
  gtk_widget_show (check_increase);

  /* ---------------------------------------------------------------------
     GConf settings
     ---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(check_increase, client, RUBRICA_KEY_INCREASE); 
  /* ---------------------------------------------------------------------  */

  /*        RADIO BUTTONS

            - ORDER BY DATE
	    - ORDER ALPHABETIC

	    default: alphabetic order
  */
  radio_date = gtk_radio_button_new_with_label (opt_ordine_group, 
						_("by creation date"));
  opt_ordine_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_date));
  gtk_widget_set_name (radio_date, "radio_date");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_DATE_ORDER, 
		       radio_date);
  gtk_table_attach (GTK_TABLE (table1), radio_date, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_show (radio_date);

  radio_alpha = gtk_radio_button_new_with_label (opt_ordine_group, 
						 _("in alphabetic order"));
  opt_ordine_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_alpha));
  gtk_widget_set_name (radio_alpha, "radio_alpha");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_ALPHA_ORDER,  
		       radio_alpha);
  gtk_table_attach (GTK_TABLE (table1), radio_alpha, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_show (radio_alpha);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_radio(radio_alpha, radio_date, client, 
				      RUBRICA_KEY_ALPHA_ORDER,
				      RUBRICA_KEY_DATE_ORDER);
  /*    ---------------------------------------------------------------------  */

  search_frame = gtk_frame_new (_(" Search "));
  gtk_box_pack_start (GTK_BOX (box_general), search_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (search_frame), 2);
  gtk_widget_show (search_frame);

  box_search = gtk_vbox_new (TRUE, 0);
  gtk_container_add (GTK_CONTAINER (search_frame), box_search);
  gtk_container_set_border_width (GTK_CONTAINER (box_search), 2);
  gtk_widget_show (box_search);

  table2 = gtk_table_new (2, 3, TRUE);
  gtk_box_pack_start (GTK_BOX (box_search), table2, TRUE, TRUE, 0);
  gtk_table_set_col_spacings (GTK_TABLE (table2), 5);
  gtk_widget_show (table2);

  label_search = gtk_label_new (_("Search on:"));
  gtk_widget_show (label_search);
  gtk_table_attach (GTK_TABLE (table2), label_search, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_search), GTK_JUSTIFY_LEFT);
  gtk_label_set_line_wrap (GTK_LABEL (label_search), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label_search), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_search), 4, 0);

  /*      CHECK BUTTON
	  
          SEARCH CASE SENSITIVE
  */
  check_case_search = gtk_check_button_new_with_label 
    (_("Default search is case sensitive"));
  gtk_widget_set_name (check_case_search, "check_case_search");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "check_case_search",
		       check_case_search);
  gtk_table_attach (GTK_TABLE (table2), check_case_search, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_case_search), 2);
  gtk_tooltips_set_tip (tooltips, check_case_search, 
			_("Uncheck for case insensitive search"), NULL);
  gtk_widget_show (check_case_search);

  /*        RADIO BUTTONS
	    
            - SEARCH ON COMPLETE STRING
	    - SEARCH ON INCOMPLETE STRING     

	    default: search in complete string
   */
  radio_complete = gtk_radio_button_new_with_label (opt_string_search_group, 
						    _("complete string"));
  opt_string_search_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_complete));
  gtk_widget_set_name (radio_complete, "radio_complete");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_COMPLETE, 
		       radio_complete);
  gtk_table_attach (GTK_TABLE (table2), radio_complete, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_show (radio_complete);

  radio_incomplete = gtk_radio_button_new_with_label (opt_string_search_group, 
						      _("incomplete string"));
  opt_string_search_group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio_incomplete));
  gtk_widget_set_name (radio_incomplete, "radio_incomplete");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_INCOMPLETE, 
		       radio_incomplete);
  gtk_table_attach (GTK_TABLE (table2), radio_incomplete, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_show (radio_incomplete);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_radio(radio_complete, radio_incomplete, client, 
				      RUBRICA_KEY_COMPLETE,
				      RUBRICA_KEY_INCOMPLETE);
  /*    ---------------------------------------------------------------------  */

  exit_frame = gtk_frame_new (_(" Exit "));
  gtk_box_pack_start (GTK_BOX (box_general), exit_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (exit_frame), 2);
  gtk_widget_show (exit_frame);

  box_exit = gtk_hbox_new (TRUE, 0);
  gtk_container_add (GTK_CONTAINER (exit_frame), box_exit);
  gtk_container_set_border_width (GTK_CONTAINER (box_exit), 2);
  gtk_widget_show (box_exit);

  /*    CHECK BUTTON
	
	EXIT

	default: ask before quit
  */
  check_exit = gtk_check_button_new_with_label(_("Exit from rubrica without confirm"));
  gtk_widget_set_name (check_exit, "check_exit");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_EXIT, check_exit);
  gtk_box_pack_start (GTK_BOX (box_exit), check_exit, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_exit), 2);
  gtk_widget_show (check_exit);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(check_exit, client, RUBRICA_KEY_EXIT);
  /*    ---------------------------------------------------------------------  */

  tips_frame = gtk_frame_new (_(" Tips "));
  gtk_widget_set_name (tips_frame, "tips_frame");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "tips_frame", tips_frame);
  gtk_box_pack_start (GTK_BOX (box_general), tips_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (tips_frame), 2);
  gtk_widget_show (tips_frame);

  box_tips = gtk_hbox_new (TRUE, 0);
  gtk_container_add (GTK_CONTAINER (tips_frame), box_tips);
  gtk_container_set_border_width (GTK_CONTAINER (box_tips), 2);
  gtk_widget_show (box_tips);

  /*    CHECK BUTTON
	
	SHOW TIPS
	
	default: show tips at startup
  */
  check_tips = gtk_check_button_new_with_label (_("Show tips at rubrica start"));
  gtk_widget_set_name (check_tips, "check_tips");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_TIPS, check_tips);
  gtk_box_pack_start (GTK_BOX (box_tips), check_tips, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (check_tips), 2);
  gtk_widget_show (check_tips);
  /*    ---------------------------------------------------------------------
	GConf settings
	---------------------------------------------------------------------  */
  rubrica_preferences_configure_check(check_tips, client, RUBRICA_KEY_TIPS);
  /*    ---------------------------------------------------------------------  */

  /*    INCREASE CALLBACK
  */
  gtk_signal_connect (GTK_OBJECT (check_increase), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
                      RUBRICA_KEY_INCREASE);

  /*    ORDERING TYPE CALLBACKS
  */
  gtk_signal_connect (GTK_OBJECT (radio_alpha), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_order_toggled),
                      RUBRICA_KEY_ALPHA_ORDER);
  gtk_signal_connect (GTK_OBJECT (radio_date), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_order_toggled),
		      RUBRICA_KEY_DATE_ORDER);

  /*    SEARCH CALLBACS
  */
  gtk_signal_connect (GTK_OBJECT (check_case_search), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
                      RUBRICA_KEY_SENSITIVE);

  gtk_signal_connect (GTK_OBJECT (radio_complete), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_search_type_toggled),
                      RUBRICA_KEY_COMPLETE);
  gtk_signal_connect (GTK_OBJECT (radio_incomplete), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_search_type_toggled),
		      RUBRICA_KEY_INCOMPLETE);

  /*    EXIT CALLBACK
  */
  gtk_signal_connect (GTK_OBJECT (check_exit), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
                      RUBRICA_KEY_EXIT);

  /*      TIPS CALLBACK
   */
  gtk_signal_connect (GTK_OBJECT (check_tips), "toggled",
                      GTK_SIGNAL_FUNC (on_check_button_toggled),
                      RUBRICA_KEY_TIPS);
  
  return (GtkWidget *) general_frame;
}


GtkWidget *rubrica_preferences_add_translation_page(GConfClient *client)
{
  GtkWidget *translation_frame;
  GtkWidget *rules_frame;
  GtkWidget *dictionary_frame;
  GtkWidget *frame_personal_data;
  GtkWidget *frame_net;
  GtkWidget *frame_telephone;
  GtkWidget *frame_notes;
  GtkWidget *io_frame;

  GtkWidget *table_net;
  GtkWidget *table_personal_data;
  GtkWidget *table_telephone;
  GtkWidget *table_notes;

  GtkWidget *box_translation;
  GtkWidget *box_rules;
  GtkWidget *box_dict;
  GtkWidget *box_default_dict;
  GtkWidget *box_user_language;
  GtkWidget *box_io;
  GtkWidget *buttonbox_io;

  GSList *opt_other_lang_group = NULL;
  GSList *opt_def_lang_group = NULL;

  GtkWidget *radio_external_dict;
  GtkWidget *radio_default_dict;
  GtkWidget *radio_italian;
  GtkWidget *radio_english;  

  GtkWidget *notebook_dict;

  GtkWidget *label_dictionary;
  GtkWidget *label_default_dict;
  GtkWidget *label_user_language;
  GtkWidget *label_address;
  GtkWidget *label_card;
  GtkWidget *label_modify;
  GtkWidget *label_delete;
  GtkWidget *label_data;
  GtkWidget *label_last_name;
  GtkWidget *label_first_name;
  GtkWidget *label_profession;
  GtkWidget *label_street;
  GtkWidget *label_street_num;
  GtkWidget *label_zip_code;
  GtkWidget *label_city;
  GtkWidget *label_province;
  GtkWidget *label_country;
  GtkWidget *label_web;
  GtkWidget *label_email_address;
  GtkWidget *label_email;
  GtkWidget *label_web_address;
  GtkWidget *entry_tel_type;
  GtkWidget *label_tel_list;
  GtkWidget *label_tel_num;
  GtkWidget *label_tel_type;
  GtkWidget *label_public_key;
  GtkWidget *label_notes;
  GtkWidget *label_io;
  GtkWidget *label_dict_name;

  GtkWidget *entry_user_language;
  GtkWidget *entry_address;
  GtkWidget *entry_card;
  GtkWidget *entry_data;
  GtkWidget *entry_first_name;
  GtkWidget *entry_last_nane;
  GtkWidget *entry_country;
  GtkWidget *entry_province;
  GtkWidget *entry_city;
  GtkWidget *entry_zip_code;
  GtkWidget *entry_street_num;
  GtkWidget *entry_street;
  GtkWidget *entry_profession;
  GtkWidget *entry_delete;
  GtkWidget *entry_modify;
  GtkWidget *entry_web_address;
  GtkWidget *entry_web;
  GtkWidget *entry_email_address;
  GtkWidget *entry_email;
  GtkWidget *entry_tel_list;
  GtkWidget *entry_tel_num;
  GtkWidget *entry_public_key;
  GtkWidget *entry_notes;

  GtkWidget *personal_tab;
  GtkWidget *net_tab;
  GtkWidget *telephone_tab;
  GtkWidget *notes_tab;

  GtkWidget *load;
  GtkWidget *save;
  GtkWidget *show_rules;

  GtkWidget *vseparator2;

  translation_frame = gtk_frame_new (_(" Rubrica Translation "));
  gtk_widget_show (translation_frame);
  gtk_container_set_border_width (GTK_CONTAINER (translation_frame), 2);

  box_translation = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (box_translation);
  gtk_container_add (GTK_CONTAINER (translation_frame), box_translation);
  gtk_container_set_border_width (GTK_CONTAINER (box_translation), 2);

  rules_frame = gtk_frame_new (_(" Rubrica's Dictionary "));
  gtk_widget_show (rules_frame);
  gtk_box_pack_start (GTK_BOX (box_translation), rules_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (rules_frame), 2);

  box_rules = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (box_rules);
  gtk_container_add (GTK_CONTAINER (rules_frame), box_rules);
  gtk_container_set_border_width (GTK_CONTAINER (box_rules), 2);

  box_dict = gtk_hbox_new (TRUE, 0);
  gtk_widget_show (box_dict);
  gtk_box_pack_start (GTK_BOX (box_rules), box_dict, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (box_dict), 2);

  label_dictionary = gtk_label_new (_("Rubrica will use:  "));
  gtk_widget_show (label_dictionary);
  gtk_box_pack_start (GTK_BOX (box_dict), label_dictionary, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_dictionary), 0, 0.5);

  /*     RADIO BUTTONS
	 
         - DEFAULT DICTIONARY
	
	 - EXTERNAL DICTIONARY
	 
	 default: use one of the default dictionary
  */

  radio_external_dict = gtk_radio_button_new_with_label 
    (opt_other_lang_group,  _("an external dictionary     "));
  opt_other_lang_group = gtk_radio_button_group(GTK_RADIO_BUTTON(radio_external_dict));
  gtk_widget_set_name (radio_external_dict, "radio_external_dict");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_EXTERNAL, 
		       radio_external_dict);
  gtk_widget_show (radio_external_dict);
  gtk_box_pack_start (GTK_BOX (box_dict), radio_external_dict, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, radio_external_dict, 
			_("uses an external dictionary when show preview"), NULL);

  radio_default_dict = gtk_radio_button_new_with_label(opt_other_lang_group, 
						       _("a default dictionary"));
  opt_other_lang_group = gtk_radio_button_group(GTK_RADIO_BUTTON (radio_default_dict));
  gtk_widget_set_name (radio_default_dict, "radio_default_dict");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_DEFAULT,
		       radio_default_dict);
  gtk_widget_show (radio_default_dict);
  gtk_box_pack_start (GTK_BOX (box_dict), radio_default_dict, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, radio_default_dict, 
			_("uses one of the following default dictionary"), NULL);

  box_default_dict = gtk_hbox_new (TRUE, 0);
  gtk_widget_show (box_default_dict);
  gtk_box_pack_start (GTK_BOX (box_rules), box_default_dict, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (box_default_dict), 2);

  label_default_dict = gtk_label_new (_("Use as my default dictionary: "));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "label_default_dict", 
		       label_default_dict);  
  gtk_widget_show (label_default_dict);
  gtk_box_pack_start (GTK_BOX (box_default_dict), label_default_dict, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_default_dict), 0, 0.5);

  /*    RADIO BUTTONS
    
        - ITALIAN DICTIONARY
	
	- ENGLISH DICTIONARY

	default: use italian dictionary
  */
  radio_italian = gtk_radio_button_new_with_label (opt_def_lang_group, _("Italian"));
  opt_def_lang_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_italian));
  gtk_widget_set_name (radio_italian, "radio_italian");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_ITALIAN, 
		       radio_italian);
  gtk_widget_show (radio_italian);
  gtk_box_pack_start (GTK_BOX (box_default_dict), radio_italian, FALSE, TRUE, 0);

  radio_english = gtk_radio_button_new_with_label (opt_def_lang_group, _("English"));
  opt_def_lang_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radio_english));
  gtk_widget_set_name (radio_english, "radio_english");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_ENGLISH, 
		       radio_english);
  gtk_widget_show (radio_english);
  gtk_box_pack_start (GTK_BOX (box_default_dict), radio_english, FALSE, TRUE, 0);

  box_user_language = gtk_hbox_new (TRUE, 0);
  gtk_widget_show (box_user_language);
  gtk_box_pack_start (GTK_BOX (box_rules), box_user_language, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (box_user_language), 2);

  label_user_language = gtk_label_new (_("Rubrica will use this language:"));
  gtk_object_set_data(GTK_OBJECT (preferences_dialog), "label_language",
		      label_user_language);
  gtk_widget_show (label_user_language);
  gtk_box_pack_start(GTK_BOX (box_user_language), label_user_language, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_user_language), 0, 0.5);
  
  /*    ENTRY TEXT

        USER LANGUAGES
   */
  entry_user_language = gtk_entry_new ();
  gtk_widget_set_name (entry_user_language, "entry_user_language");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), RUBRICA_KEY_USER_DICTIONARY, 
		       entry_user_language);
  gtk_widget_show (entry_user_language);
  gtk_box_pack_start(GTK_BOX (box_user_language), entry_user_language, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, entry_user_language, 
			_("the language's name will be used as dictionary file name"),
			NULL);

  dictionary_frame = gtk_frame_new (_(" Dictionary "));
  gtk_widget_show (dictionary_frame);
  gtk_box_pack_start (GTK_BOX (box_translation), dictionary_frame, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (dictionary_frame), 2);

  /*      dictionary notebook 
  */
  notebook_dict = gtk_notebook_new ();
  gtk_widget_set_name (notebook_dict, "notebook_dict");
  gtk_object_set_data(GTK_OBJECT (preferences_dialog), "notebook_dict",notebook_dict);
  gtk_widget_show (notebook_dict);
  gtk_container_add (GTK_CONTAINER (dictionary_frame), notebook_dict);
  gtk_container_set_border_width (GTK_CONTAINER (notebook_dict), 2);

  frame_personal_data = gtk_frame_new (_(" Personal dictionary "));
  gtk_widget_show (frame_personal_data);
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_personal_data);
  gtk_container_set_border_width (GTK_CONTAINER (frame_personal_data), 2);

  table_personal_data = gtk_table_new (7, 4, FALSE);
  gtk_widget_show (table_personal_data);
  gtk_container_add (GTK_CONTAINER (frame_personal_data), table_personal_data);
  gtk_container_set_border_width (GTK_CONTAINER (table_personal_data), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_personal_data), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_personal_data), 10);

  entry_address = gtk_entry_new ();
  gtk_widget_set_name (entry_address, "entry_address");
  gtk_object_set_data(GTK_OBJECT(preferences_dialog), "entry_address", entry_address);
  gtk_widget_show (entry_address);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_address, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_card = gtk_entry_new ();
  gtk_widget_set_name (entry_card, "entry_card");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_card", entry_card);
  gtk_widget_show (entry_card);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_card, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_data = gtk_entry_new ();
  gtk_widget_set_name (entry_data, "entry_data");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_data", entry_data);
  gtk_widget_show (entry_data);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_data, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_first_name = gtk_entry_new ();
  gtk_widget_set_name (entry_first_name, "entry_first_name");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_first_name", 
		       entry_first_name);
  gtk_widget_show (entry_first_name);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_first_name, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_last_nane = gtk_entry_new ();
  gtk_widget_set_name (entry_last_nane, "entry_last_nane");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_last_nane", 
		       entry_last_nane);
  gtk_widget_show (entry_last_nane);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_last_nane, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_country = gtk_entry_new ();
  gtk_widget_set_name (entry_country, "entry_country");
  gtk_object_set_data(GTK_OBJECT(preferences_dialog), "entry_country", entry_country);
  gtk_widget_show (entry_country);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_country, 3, 4, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_province = gtk_entry_new ();
  gtk_widget_set_name (entry_province, "entry_province");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_province", 
		       entry_province);
  gtk_widget_show (entry_province);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_province, 3, 4, 5, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_city = gtk_entry_new ();
  gtk_widget_set_name (entry_city, "entry_city");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_city", entry_city);
  gtk_widget_show (entry_city);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_city, 3, 4, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_zip_code = gtk_entry_new ();
  gtk_widget_set_name (entry_zip_code, "entry_zip_code");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_zip_code", 
		       entry_zip_code);
  gtk_widget_show (entry_zip_code);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_zip_code, 3, 4, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_street_num = gtk_entry_new ();
  gtk_widget_set_name (entry_street_num, "entry_street_num");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_street_num", 
		       entry_street_num);
  gtk_widget_show (entry_street_num);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_street_num, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_street = gtk_entry_new ();
  gtk_widget_set_name (entry_street, "entry_street");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_street", entry_street);
  gtk_widget_show (entry_street);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_street, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_profession = gtk_entry_new ();
  gtk_widget_set_name (entry_profession, "entry_profession");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_profession", 
		       entry_profession);
  gtk_widget_show (entry_profession);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_profession, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label_address = gtk_label_new (_("Address"));
  gtk_widget_show (label_address);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_address, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_address), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label_address), 0, 0.5);

  label_card = gtk_label_new (_("Card"));
  gtk_widget_show (label_card);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_card, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_card), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label_card), 0, 0.5);

  label_modify = gtk_label_new (_("Modifying"));
  gtk_widget_show (label_modify);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_modify, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_modify), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label_modify), 0, 0.5);

  label_delete = gtk_label_new (_("Deleting"));
  gtk_widget_show (label_delete);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_delete, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_delete), GTK_JUSTIFY_LEFT);
  gtk_label_set_line_wrap (GTK_LABEL (label_delete), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label_delete), 0, 0.5);

  label_data = gtk_label_new (_("Data"));
  gtk_widget_show (label_data);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_data, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_data), 0, 0.5);

  label_last_name = gtk_label_new (_("Last Name"));
  gtk_widget_show (label_last_name);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_last_name, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_last_name), 0, 0.5);

  label_first_name = gtk_label_new (_("First Name"));
  gtk_widget_show (label_first_name);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_first_name, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_first_name), 0, 0.5);

  label_profession = gtk_label_new (_("Profession"));
  gtk_widget_show (label_profession);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_profession, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_profession), 0, 0.5);

  label_street = gtk_label_new (_("Street"));
  gtk_widget_show (label_street);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_street, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_street), 0, 0.5);

  label_street_num = gtk_label_new (_("Street Number"));
  gtk_widget_show (label_street_num);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_street_num, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_street_num), 0, 0.5);

  label_zip_code = gtk_label_new (_("Zip Code"));
  gtk_widget_show (label_zip_code);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_zip_code, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_zip_code), 0, 0.5);

  label_city = gtk_label_new (_("City"));
  gtk_widget_show (label_city);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_city, 2, 3, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_city), 0, 0.5);

  label_province = gtk_label_new (_("Province"));
  gtk_widget_show (label_province);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_province, 2, 3, 5, 6,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_province), 0, 0.5);

  label_country = gtk_label_new (_("Country"));
  gtk_widget_show (label_country);
  gtk_table_attach (GTK_TABLE (table_personal_data), label_country, 2, 3, 6, 7,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_country), 0, 0.5);

  entry_delete = gtk_entry_new ();
  gtk_widget_set_name (entry_delete, "entry_delete");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_delete", entry_delete);
  gtk_widget_show (entry_delete);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_delete, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_modify = gtk_entry_new ();
  gtk_widget_set_name (entry_modify, "entry_modify");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_modify", entry_modify);
  gtk_widget_show (entry_modify);
  gtk_table_attach (GTK_TABLE (table_personal_data), entry_modify, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  personal_tab = gtk_label_new (_(" Personal "));
  gtk_widget_show (personal_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict),
			      gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook_dict),0),
			      personal_tab);

  frame_net = gtk_frame_new (_(" Net dictionary "));
  gtk_widget_show (frame_net);
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_net);
  gtk_container_set_border_width (GTK_CONTAINER (frame_net), 2);

  table_net = gtk_table_new (6, 2, FALSE);
  gtk_widget_show (table_net);
  gtk_container_add (GTK_CONTAINER (frame_net), table_net);
  gtk_container_set_border_width (GTK_CONTAINER (table_net), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_net), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_net), 2);

  entry_web_address = gtk_entry_new ();
  gtk_widget_set_name (entry_web_address, "entry_web_address");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_web_address",
		       entry_web_address);
  gtk_widget_show (entry_web_address);
  gtk_table_attach (GTK_TABLE (table_net), entry_web_address, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_web = gtk_entry_new ();
  gtk_widget_set_name (entry_web, "entry_web");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_web", entry_web);
  gtk_widget_show (entry_web);
  gtk_table_attach (GTK_TABLE (table_net), entry_web, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_email_address = gtk_entry_new ();
  gtk_widget_set_name (entry_email_address, "entry_email_address");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_email_address", 
		       entry_email_address);
  gtk_widget_show (entry_email_address);
  gtk_table_attach (GTK_TABLE (table_net), entry_email_address, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_email = gtk_entry_new ();
  gtk_widget_set_name (entry_email, "entry_email");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_email", entry_email);
  gtk_widget_show (entry_email);
  gtk_table_attach (GTK_TABLE (table_net), entry_email, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label_web = gtk_label_new (_("Web"));
  gtk_widget_set_name (label_web, "label_web");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "label_web", label_web);
  gtk_widget_show (label_web);
  gtk_table_attach (GTK_TABLE (table_net), label_web, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_web), 0, 0.5);

  label_email_address = gtk_label_new (_("Email Address"));
  gtk_widget_set_name (label_email_address, "label_email_address");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "label_email_address", 
			    label_email_address);
  gtk_widget_show (label_email_address);
  gtk_table_attach (GTK_TABLE (table_net), label_email_address, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_email_address), 0, 0.5);

  label_email = gtk_label_new (_("Email"));
  gtk_widget_set_name (label_email, "label_email");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "label_email", label_email);
  gtk_widget_show (label_email);
  gtk_table_attach (GTK_TABLE (table_net), label_email, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_email), 0, 0.5);

  label_web_address = gtk_label_new (_("Web Address"));
  gtk_widget_show (label_web_address);
  gtk_table_attach (GTK_TABLE (table_net), label_web_address, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_web_address), 0, 0.5);

  net_tab = gtk_label_new (_(" Net "));
  gtk_widget_show (net_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook_dict),1),
			      net_tab);

  frame_telephone = gtk_frame_new (_(" Telephone dictionary "));
  gtk_widget_show (frame_telephone);
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_telephone);
  gtk_container_set_border_width (GTK_CONTAINER (frame_telephone), 2);

  table_telephone = gtk_table_new (6, 2, FALSE);
  gtk_widget_show (table_telephone);
  gtk_container_add (GTK_CONTAINER (frame_telephone), table_telephone);
  gtk_container_set_border_width (GTK_CONTAINER (table_telephone), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_telephone), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_telephone), 2);

  entry_tel_list = gtk_entry_new ();
  gtk_widget_set_name (entry_tel_list, "entry_tel_list");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_tel_list", 
		       entry_tel_list);
  gtk_widget_show (entry_tel_list);
  gtk_table_attach (GTK_TABLE (table_telephone), entry_tel_list, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_tel_num = gtk_entry_new ();
  gtk_widget_set_name (entry_tel_num, "entry_tel_num");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_tel_num", 
		       entry_tel_num);
  gtk_widget_show (entry_tel_num);
  gtk_table_attach (GTK_TABLE (table_telephone), entry_tel_num, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_tel_type = gtk_entry_new ();
  gtk_widget_set_name (entry_tel_type, "entry_tel_type");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_tel_type",
		       entry_tel_type);
  gtk_widget_show (entry_tel_type);
  gtk_table_attach (GTK_TABLE (table_telephone), entry_tel_type, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label_tel_list = gtk_label_new (_("Telephone List"));
  gtk_widget_show (label_tel_list);
  gtk_table_attach (GTK_TABLE (table_telephone), label_tel_list, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_tel_list), 0, 0.5);

  label_tel_num = gtk_label_new (_("Telephone Number"));
  gtk_widget_show (label_tel_num);
  gtk_table_attach (GTK_TABLE (table_telephone), label_tel_num, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_tel_num), 0, 0.5);

  label_tel_type = gtk_label_new (_("Telephone Type"));
  gtk_widget_show (label_tel_type);
  gtk_table_attach (GTK_TABLE (table_telephone), label_tel_type, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_tel_type), 0, 0.5);

  telephone_tab = gtk_label_new (_("Telephone"));
  gtk_widget_show (telephone_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook_dict),2),
			      telephone_tab);

  frame_notes = gtk_frame_new (_(" Notes and Other dictionary "));
  gtk_widget_show (frame_notes);
  gtk_container_add (GTK_CONTAINER (notebook_dict), frame_notes);
  gtk_container_set_border_width (GTK_CONTAINER (frame_notes), 2);

  table_notes = gtk_table_new (6, 2, FALSE);
  gtk_widget_show (table_notes);
  gtk_container_add (GTK_CONTAINER (frame_notes), table_notes);
  gtk_container_set_border_width (GTK_CONTAINER (table_notes), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table_notes), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table_notes), 2);

  entry_public_key = gtk_entry_new ();
  gtk_widget_set_name (entry_public_key, "entry_public_key");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_public_key", 
		       entry_public_key);
  gtk_widget_show (entry_public_key);
  gtk_table_attach (GTK_TABLE (table_notes), entry_public_key, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_notes = gtk_entry_new ();
  gtk_widget_set_name (entry_notes, "entry_notes");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "entry_notes", entry_notes);
  gtk_widget_show (entry_notes);
  gtk_table_attach (GTK_TABLE (table_notes), entry_notes, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label_public_key = gtk_label_new (_("Public Key"));
  gtk_widget_show (label_public_key);
  gtk_table_attach (GTK_TABLE (table_notes), label_public_key, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_public_key), 0, 0.5);

  label_notes = gtk_label_new (_("Notes"));
  gtk_widget_show (label_notes);
  gtk_table_attach (GTK_TABLE (table_notes), label_notes, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_notes), 0, 0.5);

  notes_tab = gtk_label_new (_(" Notes and Other "));
  gtk_widget_show (notes_tab);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_dict), 
			      gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook_dict),3),
			      notes_tab);

  io_frame = gtk_frame_new (_(" Save and Load Dictionary"));
  gtk_widget_show (io_frame);
  gtk_box_pack_start (GTK_BOX (box_translation), io_frame, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (io_frame), 2);

  box_io = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (box_io);
  gtk_container_add (GTK_CONTAINER (io_frame), box_io);
  gtk_container_set_border_width (GTK_CONTAINER (box_io), 2);


  /*      input/output labels 
   */
  label_io = gtk_label_new (_("Dictionary name:"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "label_io", label_io);
  gtk_widget_show (label_io);
  gtk_box_pack_start (GTK_BOX (box_io), label_io, FALSE, FALSE, 0);
 
  label_dict_name = gtk_label_new ("");
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "label_dict_name", 
		       label_dict_name);
  gtk_widget_show (label_dict_name);
  gtk_box_pack_start (GTK_BOX (box_io), label_dict_name, TRUE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label_dict_name), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label_dict_name), 0, 0.5);
  
  vseparator2 = gtk_vseparator_new ();
  gtk_widget_show (vseparator2);
  gtk_box_pack_start (GTK_BOX (box_io), vseparator2, FALSE, TRUE, 0);

  buttonbox_io = gtk_hbutton_box_new ();
  gtk_widget_show (buttonbox_io);
  gtk_box_pack_start (GTK_BOX (box_io), buttonbox_io, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (buttonbox_io), 2);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (buttonbox_io), GTK_BUTTONBOX_SPREAD);
  gtk_button_box_set_spacing (GTK_BUTTON_BOX (buttonbox_io), 5);
  gtk_button_box_set_child_size (GTK_BUTTON_BOX (buttonbox_io), 80, 27);
  gtk_button_box_set_child_ipadding (GTK_BUTTON_BOX (buttonbox_io), 4, 0);

  /*    load and save dictionary buttons
  */
  load = gtk_button_new_with_label (_("Load"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "load", load);
  gtk_widget_show (load);
  gtk_container_add (GTK_CONTAINER (buttonbox_io), load);
  GTK_WIDGET_SET_FLAGS (load, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, load, _("Load dictionary and show it"), NULL);

  save = gtk_button_new_with_label (_("Save"));
  gtk_object_set_data (GTK_OBJECT (preferences_dialog), "save", save);
  gtk_widget_show (save);
  gtk_container_add (GTK_CONTAINER (buttonbox_io), save);
  GTK_WIDGET_SET_FLAGS (save, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, save, _("Save dictionary"), NULL);

  show_rules = gtk_button_new_with_label (_("Show Rules"));
  gtk_widget_show (show_rules);
  gtk_container_add (GTK_CONTAINER (buttonbox_io), show_rules);
  GTK_WIDGET_SET_FLAGS (show_rules, GTK_CAN_DEFAULT);
  gtk_tooltips_set_tip (tooltips, show_rules, _("Show translation rules"), NULL);
  /* ---------------------------------------------------------------------
     GConf settings
     ---------------------------------------------------------------------  */
  rubrica_preferences_configure_radio_dictionary(radio_external_dict, 
						 radio_default_dict, client, 
						 RUBRICA_KEY_EXTERNAL,
						 RUBRICA_KEY_DEFAULT);  

  rubrica_preferences_configure_radio(radio_italian, radio_english, client, 
				      RUBRICA_KEY_ITALIAN, RUBRICA_KEY_ENGLISH);  

  rubrica_preferences_configure_label(label_dict_name, client, 
				      RUBRICA_KEY_USER_DICTIONARY);

  rubrica_preferences_configure_entry(entry_user_language, client, 
				      RUBRICA_KEY_USER_DICTIONARY);

  /* ---------------------------------------------------------------------  */

  gtk_signal_connect (GTK_OBJECT (radio_external_dict), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_witch_dict_toggled),
                      RUBRICA_KEY_EXTERNAL);
  gtk_signal_connect (GTK_OBJECT (radio_default_dict), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_witch_dict_toggled),
                      RUBRICA_KEY_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (radio_italian), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_dictionary_toggled),
                      RUBRICA_KEY_ITALIAN);
  gtk_signal_connect (GTK_OBJECT (radio_english), "toggled",
                      GTK_SIGNAL_FUNC (on_radio_dictionary_toggled),
                      RUBRICA_KEY_ENGLISH);

  gtk_signal_connect (GTK_OBJECT (entry_user_language), "changed",
                      GTK_SIGNAL_FUNC (on_entry_user_lang_changed),
                      RUBRICA_KEY_USER_DICTIONARY);


  gtk_signal_connect (GTK_OBJECT (entry_address), "changed",
                      GTK_SIGNAL_FUNC (on_entry_address_changed),
                      RUBRICA_KEY_DICT_ADDRESS);
  gtk_signal_connect (GTK_OBJECT (entry_card), "changed",
                      GTK_SIGNAL_FUNC (on_entry_card_changed),
                      RUBRICA_KEY_DICT_CARD);
  gtk_signal_connect (GTK_OBJECT (entry_data), "changed",
                      GTK_SIGNAL_FUNC (on_entry_data_changed),
                      RUBRICA_KEY_DICT_DATA);
  gtk_signal_connect (GTK_OBJECT (entry_first_name), "changed",
                      GTK_SIGNAL_FUNC (on_entry_fn_changed),
                      RUBRICA_KEY_DICT_FIRST_NAME);
  gtk_signal_connect (GTK_OBJECT (entry_last_nane), "changed",
                      GTK_SIGNAL_FUNC (on_entry_ln_changed),
                      RUBRICA_KEY_DICT_LAST_NAME);
  gtk_signal_connect (GTK_OBJECT (entry_country), "changed",
                      GTK_SIGNAL_FUNC (on_entry_country_changed),
		      RUBRICA_KEY_DICT_COUNTRY);
  gtk_signal_connect (GTK_OBJECT (entry_province), "changed",
                      GTK_SIGNAL_FUNC (on_entry_prov_changed),
                      RUBRICA_KEY_DICT_PROVINCE);
  gtk_signal_connect (GTK_OBJECT (entry_city), "changed",
                      GTK_SIGNAL_FUNC (on_entry_city_changed),
                      RUBRICA_KEY_DICT_CITY);
  gtk_signal_connect (GTK_OBJECT (entry_zip_code), "changed",
                      GTK_SIGNAL_FUNC (on_entry_zip_changed),
                      RUBRICA_KEY_DICT_ZIP_CODE);
  gtk_signal_connect (GTK_OBJECT (entry_street_num), "changed",
                      GTK_SIGNAL_FUNC (on_entry_street_num_changed),
		      RUBRICA_KEY_DICT_STREET_NUMBER);
  gtk_signal_connect (GTK_OBJECT (entry_street), "changed",
                      GTK_SIGNAL_FUNC (on_entry_street_changed),
                      RUBRICA_KEY_DICT_STREET);
  gtk_signal_connect (GTK_OBJECT (entry_profession), "changed",
                      GTK_SIGNAL_FUNC (on_entry_prof_changed),
                      RUBRICA_KEY_DICT_PROFESSION);
  gtk_signal_connect (GTK_OBJECT (entry_delete), "changed",
                      GTK_SIGNAL_FUNC (on_entry_del_changed),
                      RUBRICA_KEY_DICT_DELETE);
  gtk_signal_connect (GTK_OBJECT (entry_modify), "changed",
                      GTK_SIGNAL_FUNC (on_entry_mod_changed),
                      RUBRICA_KEY_DICT_MODIFY);
  gtk_signal_connect (GTK_OBJECT (entry_web_address), "changed",
                      GTK_SIGNAL_FUNC (on_entry_web_address_changed),
                      RUBRICA_KEY_DICT_WEB_ADDRESS);
  gtk_signal_connect (GTK_OBJECT (entry_web), "changed",
                      GTK_SIGNAL_FUNC (on_entry_web_changed),
                      RUBRICA_KEY_DICT_WEB);
  gtk_signal_connect (GTK_OBJECT (entry_email_address), "changed",
                      GTK_SIGNAL_FUNC (on_entry_mail_address_changed),
                      RUBRICA_KEY_DICT_EMAIL_ADDRESS);
  gtk_signal_connect (GTK_OBJECT (entry_email), "changed",
                      GTK_SIGNAL_FUNC (on_entry_mail_changed),
                      RUBRICA_KEY_DICT_EMAIL);
  gtk_signal_connect (GTK_OBJECT (entry_tel_list), "changed",
                      GTK_SIGNAL_FUNC (on_entry_tel_lst_changed),
                      RUBRICA_KEY_DICT_TELEPHONE_LIST);
  gtk_signal_connect (GTK_OBJECT (entry_tel_num), "changed",
                      GTK_SIGNAL_FUNC (on_entry_tel_num_changed),
                      RUBRICA_KEY_DICT_TELEPHONE_NUMBER);
  gtk_signal_connect (GTK_OBJECT (entry_tel_type), "changed",
                      GTK_SIGNAL_FUNC (on_entry_tel_type_changed),
                      RUBRICA_KEY_DICT_TELEPHONE_TYPE);
  gtk_signal_connect (GTK_OBJECT (entry_public_key), "changed",
                      GTK_SIGNAL_FUNC (on_entry_pub_key_changed),
                      RUBRICA_KEY_DICT_PUBLIC_KEY);
  gtk_signal_connect (GTK_OBJECT (entry_notes), "changed",
                      GTK_SIGNAL_FUNC (on_entry_notes_changed),
                      RUBRICA_KEY_DICT_NOTES);

  /*      notebook dictionary buttons callbacks 
  */
  gtk_signal_connect (GTK_OBJECT (load), "clicked",
                      GTK_SIGNAL_FUNC (on_load_dictionary_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (save), "clicked",
                      GTK_SIGNAL_FUNC (on_save_dictionary_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (show_rules), "clicked",
                      GTK_SIGNAL_FUNC (on_show_rules_clicked),
                      NULL);

  return (GtkWidget *) translation_frame;
}



GtkWidget*
create_translationbox (void)
{
  GtkWidget *translationbox;
  GtkWidget *dialog_vbox1;
  GtkWidget *button_ok;
  GtkWidget *dialog_action_area1;

  /* We create it with an OK button, and then remove the button, to work
     around a bug in gnome-libs. */
  translationbox = gnome_message_box_new (_("Rubrica can use more languages, in address book preview, \nto show his fields. User can choose to use one of the \ndefault rubrica's languages (Italian or English) or can customize \nhis dictionary.\n\nIMPORTANT:\nDon't use space in your words (rubrica don't recognize words \nsepareted by space, or alike). You can use underscore, if \nyou want to separare two words.\n\nExample: \nSuppose that I want to translate \"Telephone Number\" in italian, \nI can't do \"Numero Telefonico\", but I must do \n\"Numero_Telefonico\" or \"NumeroTelefonico\""),
                              GNOME_MESSAGE_BOX_INFO,
                              GNOME_STOCK_BUTTON_OK, NULL);
  gtk_container_remove (GTK_CONTAINER (GNOME_DIALOG (translationbox)->action_area), 
			GNOME_DIALOG (translationbox)->buttons->data);
  GNOME_DIALOG (translationbox)->buttons = NULL;
  gtk_widget_set_name (translationbox, "translationbox");
  gtk_object_set_data (GTK_OBJECT (translationbox), "translationbox", translationbox);
  gtk_window_set_title (GTK_WINDOW (translationbox), _("Rubrica Translation Rules"));
  gtk_window_set_position (GTK_WINDOW (translationbox), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (translationbox), TRUE);
  gtk_window_set_policy (GTK_WINDOW (translationbox), FALSE, FALSE, TRUE);
  gnome_dialog_set_close (GNOME_DIALOG (translationbox), FALSE);

  dialog_vbox1 = GNOME_DIALOG (translationbox)->vbox;
  gtk_widget_set_name (dialog_vbox1, "dialog_vbox1");
  gtk_object_set_data (GTK_OBJECT (translationbox), "dialog_vbox1", dialog_vbox1);
  gtk_widget_show (dialog_vbox1);
  gtk_container_set_border_width (GTK_CONTAINER (dialog_vbox1), 2);

  gnome_dialog_append_button (GNOME_DIALOG (translationbox), GNOME_STOCK_BUTTON_OK);
  button_ok = GTK_WIDGET (g_list_last (GNOME_DIALOG (translationbox)->buttons)->data);
  gtk_widget_set_name (button_ok, "button_ok");
  gtk_widget_ref (button_ok);
  gtk_object_set_data (GTK_OBJECT (translationbox), "button_ok", button_ok);
  gtk_widget_show (button_ok);
  GTK_WIDGET_SET_FLAGS (button_ok, GTK_CAN_DEFAULT);

  dialog_action_area1 = GNOME_DIALOG (translationbox)->action_area;
  if (dialog_action_area1 != NULL)
    gtk_widget_set_name (dialog_action_area1, "dialog_action_area1");
  gtk_widget_ref (dialog_action_area1);
  gtk_object_set_data (GTK_OBJECT (translationbox), "dialog_action_area1", 
		       dialog_action_area1);

  gtk_signal_connect (GTK_OBJECT (translationbox), "clicked",
                      GTK_SIGNAL_FUNC (gtk_widget_destroy),
                      NULL);

  return translationbox;
}
